@@ -13,7 +13,6 @@ from slidge.util.types import LegacyAttachment
 from slixmpp import JID
 from slixmpp.exceptions import XMPPError
 
-from . import config
 from .reactions import ReactionCache
 from .util import Credentials, get_replace, server_timestamp_to_datetime
 
@@ -202,8 +201,7 @@ class Client(AuthenticationClient):
 
     @catch_all
     async def on_event(self, room: nio.MatrixRoom, event: nio.Event):
-        if config.NIO_VERBOSE:
-            self.log.debug("Event %s '%s': %r", type(event), room, event)
+        self.log.debug("Event %s '%s': %r", type(event), room, event)
 
     @catch_all
     async def on_message(self, room: nio.MatrixRoom, event: nio.RoomMessage):
@@ -232,7 +230,7 @@ class Client(AuthenticationClient):
         muc = await self.__get_muc(room)
         participant = await self.get_participant(room, event)
         muc.subject = event.topic
-        muc.subject_setter = participant.name
+        muc.subject_setter = participant
         muc.subject_date = server_timestamp_to_datetime(event)
 
     @catch_all
@@ -425,7 +423,7 @@ class Client(AuthenticationClient):
             sas = self.key_verifications.get(event.transaction_id)
 
             if sas is None:
-                self.session.send_gateway_message(f"transaction_id could not be found")
+                self.session.send_gateway_message("transaction_id could not be found")
                 return
 
             todevice_msg = sas.share_key()
@@ -443,7 +441,7 @@ class Client(AuthenticationClient):
             sas = self.key_verifications.get(event.transaction_id)
 
             if sas is None:
-                self.session.send_gateway_message(f"transaction_id could not be found")
+                self.session.send_gateway_message("transaction_id could not be found")
                 return
 
             self.session.send_gateway_message(f"{sas.get_emoji()}")
@@ -496,7 +494,7 @@ class Client(AuthenticationClient):
             sas = self.key_verifications.get(event.transaction_id)
 
             if sas is None:
-                self.session.send_gateway_message(f"transaction_id could not be found")
+                self.session.send_gateway_message("transaction_id could not be found")
                 return
 
             try:
